@@ -111,7 +111,7 @@ static OptionStruct desc[] =
 };
 
 ModeSpecOpt pipes_opts =
-{7, opts, 4, vars, desc};
+{sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
 ModStruct   pipes_description =
@@ -122,7 +122,7 @@ ModStruct   pipes_description =
  "change_pipes",
 #endif
  "change_pipes", NULL, &pipes_opts,
- 1000, 2, 5, 500, 1.0, "",
+ 1000, 2, 5, 500, 4, 1.0, "",
  "Shows a selfbuilding pipe system", 0, NULL};
 
 #endif
@@ -406,7 +406,7 @@ MakeValve(ModeInfo * mi, int newdir)
 	glCallList(pp->betweenbolts);
 	glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
 	glCallList(pp->bolts);
-	if (!MI_WIN_IS_MONO(mi)) {
+	if (!MI_IS_MONO(mi)) {
 		if (pp->system_color == MaterialRed) {
 			glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, NRAND(2) ? MaterialYellow : MaterialBlue);
 		} else if (pp->system_color == MaterialBlue) {
@@ -563,7 +563,7 @@ pinit(ModeInfo * mi, int zera)
 	pp->counter = 0;
 	pp->turncounter = 0;
 
-	if (!MI_WIN_IS_MONO(mi)) {
+	if (!MI_IS_MONO(mi)) {
 		int         collist[DEFINEDCOLORS];
 		int         i, j, lower = 1000;
 
@@ -639,29 +639,29 @@ init_pipes(ModeInfo * mi)
 	pp->window = MI_WINDOW(mi);
 	if ((pp->glx_context = init_GL(mi)) != NULL) {
 
-		reshape(mi, MI_WIN_WIDTH(mi), MI_WIN_HEIGHT(mi));
+		reshape(mi, MI_WIDTH(mi), MI_HEIGHT(mi));
 		pp->initial_rotation = -10.0;
 		pinit(mi, 1);
 
 		if (factory > 0) {
-			pp->valve = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_BigValve);
-			pp->bolts = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_Bolts3D);
-			pp->betweenbolts = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_PipeBetweenBolts);
+			pp->valve = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_BigValve);
+			pp->bolts = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_Bolts3D);
+			pp->betweenbolts = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_PipeBetweenBolts);
 
-			pp->elbowbolts = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_ElbowBolts);
-			pp->elbowcoins = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_ElbowCoins);
+			pp->elbowbolts = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_ElbowBolts);
+			pp->elbowcoins = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_ElbowCoins);
 
-			pp->guagehead = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_GuageHead);
-			pp->guageface = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_GuageFace);
-			pp->guagedial = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_GuageDial);
-			pp->guageconnector = BuildLWO(MI_WIN_IS_WIREFRAME(mi), &LWO_GuageConnector);
+			pp->guagehead = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_GuageHead);
+			pp->guageface = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_GuageFace);
+			pp->guagedial = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_GuageDial);
+			pp->guageconnector = BuildLWO(MI_IS_WIREFRAME(mi), &LWO_GuageConnector);
 		}
 		/* else they are all 0, thanks to calloc(). */
 
-		if (MI_BATCHCOUNT(mi) < 1 || MI_BATCHCOUNT(mi) > NofSysTypes + 1) {
+		if (MI_COUNT(mi) < 1 || MI_COUNT(mi) > NofSysTypes + 1) {
 			pp->system_type = NRAND(NofSysTypes) + 1;
 		} else {
-			pp->system_type = MI_BATCHCOUNT(mi);
+			pp->system_type = MI_COUNT(mi);
 		}
 
 		if (MI_CYCLES(mi) > 0 && MI_CYCLES(mi) < 11) {
@@ -709,7 +709,7 @@ draw_pipes(ModeInfo * mi)
 	if (rotatepipes)
 		glRotatef(pp->initial_rotation, 0.0, 1.0, 0.0);
 
-	if (!MI_WIN_IS_ICONIC(mi)) {
+	if (!MI_IS_ICONIC(mi)) {
 		/* Width/height ratio handled by gluPerspective() now. */
 		glScalef(Scale4Window, Scale4Window, Scale4Window);
 	} else {
