@@ -351,8 +351,8 @@ char *progclass = "Pedal";
  * should be dark.
  */
 char *defaults [] = {
-  "Pedal.background:		black",		/* to placate SGI */
-  "Pedal.foreground:		white",
+  "*background:			black",
+  "*foreground:			white",
   "*delay:			5",
   "*fadedelay:			200000",
   "*maxlines:			1000",
